@@ -100,15 +100,20 @@ class ErrorHandler(object):
             if value_json and isinstance(value_json, basestring):
                 import json
                 try:
-                  value = json.loads(value_json)
-                  status = value.get('error', None)
-                  if status is None:
-                      status = value["status"]
-                      message = value["value"]["message"]
-                  else:
-                      message = value.get('message', None)
+                    value = json.loads(value_json)
+                    status = value.get('error', None)
+                    if status is None:
+                        status = value["status"]
+                        message = value["value"]
+                        if not isinstance(message, basestring):
+                            try:
+                                message = message['message']
+                            except TypeError:
+                                message = None
+                    else:
+                        message = value.get('message', None)
                 except ValueError:
-                  pass
+                    pass
 
         exception_class = ErrorInResponseException
         if status in ErrorCode.NO_SUCH_ELEMENT:
@@ -151,13 +156,13 @@ class ErrorHandler(object):
             exception_class = MoveTargetOutOfBoundsException
         else:
             exception_class = WebDriverException
-        if value == '':
+        if value == '' or value is None:
             value = response['value']
         if isinstance(value, basestring):
             if exception_class == ErrorInResponseException:
                 raise exception_class(response, value)
             raise exception_class(value)
-        if message != "" and 'message' in value:
+        if message == "" and 'message' in value:
             message = value['message']
 
         screen = None
@@ -188,4 +193,4 @@ class ErrorHandler(object):
         raise exception_class(message, screen, stacktrace)
 
     def _value_or_default(self, obj, key, default):
-      return obj[key] if key in obj else default
+        return obj[key] if key in obj else default
